package com.jkcredit.query.record.config;

import lombok.extern.slf4j.Slf4j;
import org.apache.http.HttpHost;
import org.apache.http.auth.AuthScope;
import org.apache.http.auth.UsernamePasswordCredentials;
import org.apache.http.client.CredentialsProvider;
import org.apache.http.impl.client.BasicCredentialsProvider;
import org.elasticsearch.client.RequestOptions;
import org.elasticsearch.client.RestClient;
import org.elasticsearch.client.RestClientBuilder;
import org.elasticsearch.client.RestHighLevelClient;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

/**
 * @author xusonglin
 * @version V1.0
 **/
@Configuration
@Slf4j
public class EsConfig {
    @Value("${ElasticSearch.userFilePath}")
    private String userFilePath;

    @Bean
    public RestHighLevelClient esRestClient() {
        Properties properties = new Properties();
        InputStream in;
        try {
            in = new FileInputStream(new File(userFilePath));
            properties.load(in);
        } catch (IOException e) {
            log.error("读取Es配置文件失败:", e);
        }
        String username = properties.getProperty("username");
        String password = properties.getProperty("password");
        String host = properties.getProperty("host");
        int port = Integer.parseInt(properties.getProperty("port"));

        RestClientBuilder builder = null;
        // 可以指定多个es
        builder = RestClient.builder(
                new HttpHost(host, port, "http"));

        CredentialsProvider credentialsProvider = new BasicCredentialsProvider();
        credentialsProvider.setCredentials(AuthScope.ANY,
                //es账号密码
                new UsernamePasswordCredentials(username, password));
        builder.setHttpClientConfigCallback(f -> f.setDefaultCredentialsProvider(credentialsProvider));
        RestHighLevelClient client = new RestHighLevelClient(builder);
        return client;
    }

//    @Bean
//    public RestHighLevelClient esRestClient() {
//        RestClientBuilder builder = null;
//        // 可以指定多个es
//        builder = RestClient.builder(
//                new HttpHost("192.168.50.17", 9200, "http"),
//                new HttpHost("192.168.50.18", 9200, "http"),
//                new HttpHost("192.168.50.19", 9200, "http"));
//        RestHighLevelClient client = new RestHighLevelClient(builder);
//        return client;
//    }
}
