package com.jkcredit.query.record.service.impl;

import com.jkcredit.query.record.constant.CommonConstant;
import com.jkcredit.query.record.service.TokenService;
import com.jkcredit.query.record.util.JwtTokenUtil;
import lombok.extern.slf4j.Slf4j;
import org.jose4j.json.JsonUtil;
import org.jose4j.jwk.RsaJsonWebKey;
import org.jose4j.lang.JoseException;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.security.PublicKey;
import java.util.HashMap;
import java.util.Map;

/**
 * @author xusonglin
 * @version V1.0
 **/
@Service
@Slf4j
public class TokenServiceImpl implements TokenService {
    @Value("${user.name}")
    private String userName;
    @Value("${user.key}")
    private String userKey;
    @Value("${user.secret}")
    private String userSecret;
    @Value("${user.salt}")
    private String userSalt;

    @Override
    public String getToken(String clientKey, String clientSecret) {
        Map<String, Object> claims = new HashMap<>();
        claims.put("client_key", clientKey);
        claims.put("client_secret", clientSecret);
        return JwtTokenUtil.generateToken(userName, claims);
    }

    @Override
    public boolean validateToken(String token) {
        PublicKey publicKey;
        try {
            publicKey = new RsaJsonWebKey(JsonUtil.parseJson(CommonConstant.TOKEN_PUBLIC_KEY)).getPublicKey();
        } catch (JoseException e) {
            log.error("tokenParseException:", e);
            return false;
        }
        String subject = JwtTokenUtil.parseToken(token, publicKey);
        if (subject != null && subject.equals(userName)) {
            return true;
        } else {
            return false;
        }
    }
}
