package com.jkcredit.query.record.util;

import com.jkcredit.query.record.constant.CommonConstant;
import io.jsonwebtoken.Claims;
import io.jsonwebtoken.Jwts;
import org.jose4j.json.JsonUtil;
import org.jose4j.jwk.RsaJsonWebKey;
import org.jose4j.jws.AlgorithmIdentifiers;
import org.jose4j.jws.JsonWebSignature;
import org.jose4j.jwt.JwtClaims;
import org.jose4j.jwt.NumericDate;
import org.jose4j.lang.JoseException;

import java.security.PrivateKey;
import java.security.PublicKey;
import java.util.Map;

public class JwtTokenUtil {
    public static String generateToken(String subject, Map<String, Object> user) {
        JwtClaims claims = new JwtClaims();
        claims.setGeneratedJwtId();
        claims.setIssuedAtToNow();
        //过期时间一定要设置，并且小于7天
        NumericDate date = NumericDate.now();
        date.addSeconds(60*60);
        claims.setExpirationTime(date);
        claims.setSubject(subject);
        //添加自定义参数，所有值请都使用String类型
        claims.setClaim("client_key", user.get("client_key"));
        claims.setClaim("client_secret", user.get("client_secret"));

        JsonWebSignature jws = new JsonWebSignature();
        jws.setAlgorithmHeaderValue(AlgorithmIdentifiers.RSA_USING_SHA256);
        //必须设置
        jws.setKeyIdHeaderValue(CommonConstant.KEY_ID);
        jws.setPayload(claims.toJson());
        String jwtResult = "";
        try {
            PrivateKey privateKey = new RsaJsonWebKey(JsonUtil.parseJson(CommonConstant.TOKEN_PRIVATE_KEY)).getPrivateKey();
            jws.setKey(privateKey);
            jwtResult = jws.getCompactSerialization();
        } catch (JoseException e) {
            e.printStackTrace();
        }
        return jwtResult;
    }

    public static String parseToken(String token, PublicKey salt) {
        String subject = null;
        try {
            Claims claims = Jwts.parser()
                    .setSigningKey(salt)
                    .parseClaimsJws(token).getBody();
            subject = claims.getSubject();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return subject;
    }
}
